import os
USER_HOME=os.path.expanduser('~')

line0 = "import fire\n"
lineN = "\nfire.Fire()"

def inject_fire(path):
    with open(path, 'r', encoding='utf-8') as f:
        content = f.read()
    with open(path, 'w', encoding='utf-8') as f:
        f.write(line0 + content + lineN)


def remove_fire(path):
    with open(path, 'r', encoding='utf-8') as f:
        content = f.read()
    assert content.startswith(line0)
    assert content.endswith(lineN)
    content = content[len(line0):-len(lineN)]
    with open(path, 'w', encoding='utf-8') as f:
        f.write("".join(content))




import os
import sys
from .utils import CmdUtil,IoUtil
from .config import PACKGAE_CONFIG_FILENAME
from .package import Package
os.environ['ANSI_COLORS_DISABLED']="1"
import fire
from . import apis

def load_pkg_info():
    pkg_info = IoUtil.json_load(os.path.join(os.getcwd(), PACKGAE_CONFIG_FILENAME))
    return pkg_info

class CLI:


    def hi(cls):
        print('Hi, welcome to use pkman !'.center(50, '*'))

    @classmethod
    def upgradeself(cls):
        CmdUtil.run_command([sys.executable,'-m','pip','install','-U','-i','https://pypi.org/simple','pkman'])
    @classmethod
    def us(cls):
        return cls.upgradeself()
    @classmethod
    def cmd(cls, *args, **kwargs):
        CmdUtil.run_command(sys.argv[2:])
    @classmethod
    def build(cls):
        pass
    @classmethod
    def config(cls):
        pass
    @classmethod
    def docs(cls):
        pass
    @classmethod
    def init(cls):
        apis.init()
    @classmethod
    def gitsetup(cls,branch):
        Package(os.getcwd()).gitsetup(branch)
    @classmethod
    def install(cls):
        pass
    @classmethod
    def list(cls):
        pass
    @classmethod
    def ls(cls):
        pass
    @classmethod
    def login(cls):
        pass
    @classmethod
    def logout(cls):
        pass
    @classmethod
    def publish(cls):
        pass
    @classmethod
    def run(cls,cmd):
        pkg_info=load_pkg_info()
        scripts=pkg_info['scripts']
        if cmd in scripts:
            CmdUtil.run_command([scripts[cmd]])
        else:
            raise Exception('Command not found: %s'%(cmd))
    @classmethod
    def search(cls):
        pass
    @classmethod
    def uninstall(cls):
        pass
    @classmethod
    def unpublish(cls):
        pass
    @classmethod
    def update(cls):
        pass
    @classmethod
    def version(cls):
        pkg_info=load_pkg_info()
        print(pkg_info['version'])
    @classmethod
    def test(cls):
        return cls.run('test')


    @classmethod
    def testsysargv(cls, *args, **kwargs):
        import sys
        print("sys.argv:", sys.argv)
        print("executable:", sys.executable)

def main():
    fire.Fire(CLI())

if __name__ == '__main__':
    main()


import os
import sys
import requests
from .utils import CmdUtil,IoUtil,StringUtil,PathUtil,FireUtil
from .config import PACKGAE_CONFIG_FILENAME
os.environ['ANSI_COLORS_DISABLED']="1"
import fire
from . import apis
from freehub import apis as fh_api
from freehub.apis import Address
from .apis import app_data_manager
from .package import Package


def fetch_web_text(url):
    return requests.get(url).text
def load_pkg_info():
    pkg_info = IoUtil.json_load(os.path.join(os.getcwd(), PACKGAE_CONFIG_FILENAME))
    return pkg_info
class TYPES:
    class WEB_TEXT:
        pass
    class GIT_FILE:
        pass
    class PACKAGE:
        pass
def complete_address(address):
    return fh_api.get_complete_address(address)
def run_package(path,args):
    p=Package(path)
    p.install_dependencies()
    p.run(args)
class Cli:
    @classmethod
    def pkx(cls,address: str, *args, **kwargs):

        if address.startswith('http://') or address.startswith('https://'):
            text = fetch_web_text(address)
            filename = StringUtil.hash_text(address)[:10] + '.py'
            file_path = app_data_manager.tempfile(filename)
            IoUtil.write_txt(text, file_path)
            CmdUtil.run_file(file_path, sys.argv[2:])
        else:
            addr = Address.from_url(Address.get_complete_address(address))
            branch_addr = Address(addr.protocol, addr.host, addr.username, addr.repo_name, addr.branch_name, '/')
            branch_dir = fh_api.fetch(branch_addr.to_url())
            dst_path = PathUtil.join_path(branch_dir, addr.rel_path)
            if os.path.isdir(dst_path):
                run_package(dst_path, sys.argv[2:])
            else:
                CmdUtil.run_file(dst_path, sys.argv[2:],extend_path=[os.path.dirname(dst_path)])

    @classmethod
    def pkfire(cls, address: str, *args, **kwargs):
        if address.startswith('http://') or address.startswith('https://'):
            text = fetch_web_text(address)
            filename = StringUtil.hash_text(address)[:10] + '.py'
            file_path = app_data_manager.tempfile(filename)
            IoUtil.write_txt(text, file_path)
            CmdUtil.run_file(file_path, sys.argv[2:],fire=True)
        else:
            addr = Address.from_url(Address.get_complete_address(address))
            branch_addr = Address(addr.protocol, addr.host, addr.username, addr.repo_name, addr.branch_name, '/')
            branch_dir = fh_api.fetch(branch_addr.to_url())
            dst_path = PathUtil.join_path(branch_dir, addr.rel_path)
            if os.path.isdir(dst_path):
                run_package(dst_path, sys.argv[2:])
            else:
                CmdUtil.run_file(dst_path, sys.argv[2:], extend_path=[os.path.dirname(dst_path)],fire=True)
def main():
    fire.Fire(Cli().pkx)
if __name__ == '__main__':
    main()


import setuptools
import os, glob
from version import version_up
with open("README.md", "r") as fh:
    long_description = fh.read()

packages=setuptools.find_packages(exclude=['local','local.*'])

print('packages:', packages)

version = version_up()
print("version:", version)
setuptools.setup(
    executable=True,
    name="pkman",  # Replace with your own username
    version=version,
    author="Wang Pei",
    author_email="1535376447@qq.com",
    description="A python package manager inspired by npm.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitee.com/peiiii/pkman",
    packages=packages,
    package_dir={'pkman': 'pkman'},
    install_requires=[
        'fire',
        'codemaker>=0.0.2.1',
        'codetmpl>=0.0.1.2',
        'build',
        'twine',
        'requests',
        'freehub>=0.1.3.0'
                    ],
    entry_points={
        'console_scripts': [
            'pkman = pkman.clitools.cli:main',
            'pkx = pkman.clitools.pkx:main',
            'pkfire = pkman.clitools.pkfire:main',
        ]
    },
    include_package_data=True,
    package_data={
        'pkman': [
            'data/*', 'data/*/*', 'data/*/*/*', 'data/*/*/*/*', 'data/*/*/*/*/*', 'data/*/*/*/*/*/*',
            'data/*/*/*/*/*/*/*',
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.0',
)


import json
import os.path

from .utils import IoUtil,OsUtil
from .config import PACKGAE_CONFIG_FILENAME
from .utils.AppDataManager import AppDataManager
from .utils import CmdUtil,IoUtil,StringUtil,PathUtil,FireUtil

app_data_manager=AppDataManager('.pkman')
def init(root_path=None):
    if not root_path:
        root_path=os.getcwd()
    if not OsUtil.is_empty_dir(root_path):
        raise Exception('Not an empty directory:',root_path)
    def input_field(description, default, keep_empty):
        res = input('%s: (%s)' % (description, default)).strip() if default is not None else input(
            '%s: ' % (description)).strip()
        if res:
            return res
        elif default is not None:
            return default
        elif keep_empty:
            return ""
        else:
            return default

    def field(description, default=None, keep_empty=False):
        return dict(description=description, default=default, keep_empty=keep_empty)

    form = dict(
        name=field(description="package name", default=os.path.basename(os.path.abspath(os.getcwd()))),
        version=field(description="version", default="0.0.0.1"),
        description=field(description="description", keep_empty=True),
        entry_point=field(description="entry point", default="main.py"),
        test_command=field(description="test command"),
        git_repository=field(description="git repository"),
        keywords=field(description="keywords"),
        author=field(description="author", keep_empty=True),
        license=field(description="license", default='MIT'),
        python_requires=field(description="required python version", default='>=3.0'),
    )
    extra_fields = dict(
        dependencies=[],
        author_email="",
    )
    def fill_form(form):
        result = {}
        for k, f in form.items():
            v = input_field(f['description'], f['default'], f["keep_empty"])
            if v is not None:
                result[k] = v
        return result

    info = fill_form(form)
    if "test_command" in info.keys():
        test_command = info.pop("test_command")
    else:
        test_command = 'echo "Error: no test specified"'
    info["scripts"] = {"test": test_command}

    if "git_repository" in info.keys():
        repository = {
            "type": "git",
            "url": info.pop("git_repository")
        }
        info["repository"]=repository
    info.update(extra_fields)
    pkg_config_path=os.path.join(root_path,PACKGAE_CONFIG_FILENAME)
    IoUtil.json_dump(info,pkg_config_path,indent=2)
    print(IoUtil.read_txt(pkg_config_path))
    return info



